==> mothership-7.x-1.10.tar.gz: mothership/mothership/templates/field.tpl.php <==
<?php
// $Id: field.tpl.php,v 1.13 2010/03/26 17:14:45 dries Exp $

/**
 * @file field.tpl.php
 * Default template implementation to display the value of a field.
 *
 * @see theme_field()
 *
 * Available variables:
 * - $items: An array of field values. Use render() to output them.
 * - $label: The item label.
 * - $label_hidden: Whether the label display is set to 'hidden'.
 * - $classes: String of classes that can be used to style contextually through
 *   CSS. It can be manipulated through the variable $classes_array from
 *   preprocess functions. The default values can be one or more of the
 *   following:
 *   - field: The current template type, i.e., "theming hook".
 *   - field-name-[field_name]: The current field name. For example, if the
 *     field name is "field_description" it would result in
 *     "field-name-field-description".
 *   - field-type-[field_type]: The current field type. For example, if the
 *     field type is "text" it would result in "field-type-text".
 *   - field-label-[label_display]: The current label position. For example, if
 *     the label position is "above" it would result in "field-label-above".
 *
 * Other variables:
 * - $element['#object']: The entity to which the field is attached.
 * - $element['#view_mode']: View mode, e.g. 'full', 'teaser'...
 * - $element['#field_name']: The field name.
 * - $element['#field_type']: The field type.
 * - $element['#field_language']: The field language.
 * - $element['#field_translatable']: Whether the field is translatable or not.
 * - $element['#label_display']: Position of label display, inline, above, or
 *   hidden.
 * - $field_name_css: The css-compatible field name.
 * - $field_type_css: The css-compatible field type.
 * - $classes_array: Array of html class attribute values. It is flattened
 *   into a string within the variable $classes.
 *
 * @see template_preprocess_field()
 * @see theme_field()
 */

//field--image.tpl.php
?>

<div class="<?php print $classes; ?>"<?php print $attributes; ?>>
  <?php print $mothership_poorthemers_helper;  ?>  
  <?php if (!$label_hidden) : ?>
    <span<?php print $title_attributes; ?>><?php print $label ?>:&nbsp;</span>
  <?php endif; ?>

  <?php if(count($items) > 1 ){ ?>
    <div class="field-items"<?php print $content_attributes; ?>>
      <?php foreach ($items as $delta => $item) : ?>
        <div class="field-item <?php print $delta % 2 ? 'odd' : 'even'; ?>"<?php print $item_attributes[$delta]; ?>><?php print render($item); ?></div>
      <?php endforeach; ?>
    </div>
  <?php }else{ ?>
      <?php foreach ($items as $delta => $item) : ?>
        <?php print render($item); ?>
      <?php endforeach; ?>      
  <?php } ?>
</div>

==> mothership-7.x-1.12.tar.gz: mothership/mothership/templates/field.tpl.php <==
<?php
// $Id: field.tpl.php,v 1.13 2010/03/26 17:14:45 dries Exp $

/**
 * @file field.tpl.php
 * Default template implementation to display the value of a field.
 *
 * @see theme_field()
 *
 * Available variables:
 * - $items: An array of field values. Use render() to output them.
 * - $label: The item label.
 * - $label_hidden: Whether the label display is set to 'hidden'.
 * - $classes: String of classes that can be used to style contextually through
 *   CSS. It can be manipulated through the variable $classes_array from
 *   preprocess functions. The default values can be one or more of the
 *   following:
 *   - field: The current template type, i.e., "theming hook".
 *   - field-name-[field_name]: The current field name. For example, if the
 *     field name is "field_description" it would result in
 *     "field-name-field-description".
 *   - field-type-[field_type]: The current field type. For example, if the
 *     field type is "text" it would result in "field-type-text".
 *   - field-label-[label_display]: The current label position. For example, if
 *     the label position is "above" it would result in "field-label-above".
 *
 * Other variables:
 * - $element['#object']: The entity to which the field is attached.
 * - $element['#view_mode']: View mode, e.g. 'full', 'teaser'...
 * - $element['#field_name']: The field name.
 * - $element['#field_type']: The field type.
 * - $element['#field_language']: The field language.
 * - $element['#field_translatable']: Whether the field is translatable or not.
 * - $element['#label_display']: Position of label display, inline, above, or
 *   hidden.
 * - $field_name_css: The css-compatible field name.
 * - $field_type_css: The css-compatible field type.
 * - $classes_array: Array of html class attribute values. It is flattened
 *   into a string within the variable $classes.
 *
 * @see template_preprocess_field()
 * @see theme_field()
 */

//field--image.tpl.php
?>

<!-- field.tpl -->
<div <?php if($classes) {?>class="<?php print $classes; ?>"<?php } ?><?php print $attributes; ?>>
  <?php print $mothership_poorthemers_helper;  ?>  

  <?php if (!$label_hidden) : ?>
    <label<?php print $title_attributes; ?>><?php print $label ?>:&nbsp;</label>
  <?php endif; ?>

  <?php if(count($items) > 1 ){ ?>
    <div class="field-items"<?php print $content_attributes; ?>>
      <?php foreach ($items as $delta => $item) : ?>
        <div class="field-item <?php print $delta % 2 ? 'odd' : 'even'; ?>"<?php print $item_attributes[$delta]; ?>><?php print render($item); ?></div>
      <?php endforeach; ?>
    </div>
  <?php }else{ ?>
      <?php foreach ($items as $delta => $item) : ?>
        <?php print render($item); ?>
      <?php endforeach; ?>      
  <?php } ?>
</div>
